Crate ucifer

Crate ucifer 

Ucifer

Latest Release pipeline status coverage report

OpenWrt’s UCI (Unified Configuration Interface) implementation in Rust.

This implementation differs from libuci that:

  • It is thread-safe
  • Simpler, document-oriented API
  • Proper documentation
  • No staging directory in filesystem, no context. All configuration is imported into in-memory document, which then can be queried, modified and exported.

Implementation is not fully complete, see syntax notice.

Re-exports

pub use document::ConfigOption;
pub use document::Document;
pub use syntax::Directive;

Modules

document
Represents model of the configuration in a structured manner.
syntax
Syntax unit Directive definition and parsing facilities for the UCI configuration file format